@@ -26,7 +26,7 @@ setLocalTranslate('cl_console3', sys.modules[__name__])
 
 def passphrase_callback(v):
     if type(v) == int or not v:
-        return None
+        return ""
     return str(v)
 
 
@@ -92,7 +92,7 @@ def makeRequest(pubkey, pkey, serv_host, auto=False):
         name.C = lang  # Двухсимвольный код страны (Country);
     req.set_subject_name(name)
 
-    ext1 = X509.new_extension('Comment', 'Auto Generated')
+    ext1 = X509.new_extension('nsComment', 'Auto Generated')
     extstack = X509.X509_Extension_Stack()
     extstack.push(ext1)
     req.add_extensions(extstack)
