@@ -26,6 +26,7 @@ from calculate.core.server.api_types import ArrayReturnedMessage, TableAdapter
 from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
 from calculate.core.server.local_call import print_brief_group
 from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.utils.files import readFile
 from sudsds import MethodNotFound
 
 _ = lambda x: x
@@ -85,7 +86,7 @@ def print_brief(view, brief_label):
 def _return_revoked_serials(crlfile):
     try:
         serials = []
-        crltext = open(crlfile, 'r').read()
+        crltext = readFile(crlfile)
         crl = crypto.load_crl(crypto.FILETYPE_PEM, crltext)
         revs = crl.get_revoked()
         for revoked in revs:
@@ -119,12 +120,13 @@ def _create_obj(client, method):
 
 
 def get_view_params(client, method, step=None, expert=None, brief=None,
-                    onlyhelp=False, dispatch_usenew=False):
+                    onlyhelp=False, dispatch_usenew=False, unknown_args=[]):
     view_params = _create_obj(client, method)
     view_params.step = step
     view_params.expert = expert
     view_params.brief = brief
     view_params.onlyhelp = onlyhelp
+    view_params.conargs.string = unknown_args
     view_params.dispatch_usenew = dispatch_usenew
     return view_params
 
